package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BasePlanInfo;

/**
 * 计划信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-23
 */
public interface BasePlanInfoMapper 
{
    /**
     * 查询计划信息
     * 
     * @param planid 计划信息ID
     * @return 计划信息
     */
    public BasePlanInfo selectBasePlanInfoById(String planid);

    /**
     * 查询计划信息列表
     * 
     * @param basePlanInfo 计划信息
     * @return 计划信息集合
     */
    public List<BasePlanInfo> selectBasePlanInfoList(BasePlanInfo basePlanInfo);

    /**
     * 新增计划信息
     * 
     * @param basePlanInfo 计划信息
     * @return 结果
     */
    public int insertBasePlanInfo(BasePlanInfo basePlanInfo);

    /**
     * 修改计划信息
     * 
     * @param basePlanInfo 计划信息
     * @return 结果
     */
    public int updateBasePlanInfo(BasePlanInfo basePlanInfo);

    /**
     * 删除计划信息
     * 
     * @param planid 计划信息ID
     * @return 结果
     */
    public int deleteBasePlanInfoById(String planid);

    /**
     * 批量删除计划信息
     * 
     * @param planids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBasePlanInfoByIds(String[] planids);
}
